pub struct BgpAnnouncement {
pub address_lot_block_id: Uuid,
pub announce_set_id: Uuid,
pub network: IpNet,
}Expand description
A BGP announcement tied to an address lot block.
JSON schema
{
"description": "A BGP announcement tied to an address lot block.",
"type": "object",
"required": [
"address_lot_block_id",
"announce_set_id",
"network"
],
"properties": {
"address_lot_block_id": {
"description": "The address block the IP network being announced is
drawn from.",
"type": "string",
"format": "uuid"
},
"announce_set_id": {
"description": "The id of the set this announcement is a part of.",
"type": "string",
"format": "uuid"
},
"network": {
"description": "The IP network being announced.",
"allOf": [
{
"$ref": "#/components/schemas/IpNet"
}
]
}
}
}Fields
address_lot_block_id: UuidThe address block the IP network being announced is drawn from.
announce_set_id: UuidThe id of the set this announcement is a part of.
network: IpNetThe IP network being announced.
Implementations
Sourceimpl BgpAnnouncement
impl BgpAnnouncement
pub fn builder() -> BgpAnnouncement