pub struct Binint16 {
pub count: u64,
pub range: BinRangeint16,
}Expand description
Type storing bin edges and a count of samples within it.
JSON schema
{
"description": "Type storing bin edges and a count of samples within
it.",
"type": "object",
"required": [
"count",
"range"
],
"properties": {
"count": {
"description": "The total count of samples in this bin.",
"type": "integer",
"format": "uint64",
"minimum": 0.0
},
"range": {
"description": "The range of the support covered by this bin.",
"allOf": [
{
"$ref": "#/components/schemas/BinRangeint16"
}
]
}
}
}Fields
count: u64The total count of samples in this bin.
range: BinRangeint16The range of the support covered by this bin.
Implementations