pub struct InstanceNetworkInterfaceCreate {
pub description: String,
pub ip_config: PrivateIpStackCreate,
pub name: Name,
pub subnet_name: Name,
pub vpc_name: Name,
}Expand description
Create-time parameters for an InstanceNetworkInterface
JSON schema
{
"description": "Create-time parameters for an
`InstanceNetworkInterface`",
"type": "object",
"required": [
"description",
"name",
"subnet_name",
"vpc_name"
],
"properties": {
"description": {
"type": "string"
},
"ip_config": {
"description": "The IP stack configuration for this
interface.\n\nIf not provided, a default configuration will be used,
which creates a dual-stack IPv4 / IPv6 interface.",
"default": {
"type": "dual_stack",
"value": {
"v4": {
"ip": {
"type": "auto"
},
"transit_ips": []
},
"v6": {
"ip": {
"type": "auto"
},
"transit_ips": []
}
}
},
"allOf": [
{
"$ref": "#/components/schemas/PrivateIpStackCreate"
}
]
},
"name": {
"$ref": "#/components/schemas/Name"
},
"subnet_name": {
"description": "The VPC Subnet in which to create the interface.",
"allOf": [
{
"$ref": "#/components/schemas/Name"
}
]
},
"vpc_name": {
"description": "The VPC in which to create the interface.",
"allOf": [
{
"$ref": "#/components/schemas/Name"
}
]
}
}
}Fields
description: Stringip_config: PrivateIpStackCreateThe IP stack configuration for this interface.
If not provided, a default configuration will be used, which creates a dual-stack IPv4 / IPv6 interface.
name: Namesubnet_name: NameThe VPC Subnet in which to create the interface.
vpc_name: NameThe VPC in which to create the interface.
Implementations