pub struct MulticastGroupResultsPage {
pub items: Vec<MulticastGroup>,
pub next_page: Option<String>,
}Expand description
A single page of results
JSON schema
{
"description": "A single page of results",
"type": "object",
"required": [
"items"
],
"properties": {
"items": {
"description": "list of items on this page of results",
"type": "array",
"items": {
"$ref": "#/components/schemas/MulticastGroup"
}
},
"next_page": {
"description": "token used to fetch the next page of results (if
any)",
"type": [
"string",
"null"
]
}
}
}Fields
items: Vec<MulticastGroup>list of items on this page of results
next_page: Option<String>token used to fetch the next page of results (if any)
Implementations
Sourceimpl MulticastGroupResultsPage
impl MulticastGroupResultsPage
pub fn builder() -> MulticastGroupResultsPage